@@ -345,7 +345,7 @@ class ImageCache:
             # Finally, update the db's schema version stamp to the app's requested version
             self.__db.execute('DELETE FROM db_info')
             self.__db.execute('INSERT INTO db_info VALUES(?)', (required_db_schema_version,))
-
+            self.__db.commit()
 
     # --- Returns a set of folders matching any of
     #     - Found on disk, but not currently in the 'folder' table
@@ -356,6 +356,7 @@ class ImageCache:
         out_of_date_folders = []
         sql_select = "SELECT * FROM folder WHERE name = ?"
         for dir in [d[0] for d in os.walk(self.__picture_dir, followlinks=self.__follow_links)]:
+            if os.path.basename(dir)[0] == '.': continue # ignore hidden folders
             mod_tm = int(os.stat(dir).st_mtime)
             found = self.__db.execute(sql_select, (dir,)).fetchone()
             if not found or found['last_modified'] < mod_tm or found['missing'] == 1:
