@@ -6,7 +6,7 @@ import ssl
 import locale
 from distutils.dir_util import copy_tree
 
-from picframe import model, viewer_display, controller, interface_kbd, interface_http, __version__
+from picframe import model, viewer_display, controller, interface_http, __version__
 
 PICFRAME_DATA_DIR = 'picframe_data'
 
@@ -135,9 +135,6 @@ def main():
     c = controller.Controller(m, v)
     c.start()
 
-    if m.get_model_config()['use_kbd']:
-        interface_kbd.InterfaceKbd(c) # TODO make kbd failsafe
-
     mqtt_config = m.get_mqtt_config()
     if mqtt_config['use_mqtt']:
         from picframe import interface_mqtt
